==> gds-2.17.1.tar.gz: gds-2.17.1/GUI/ligogui/TLGErrorDlg.cc <==
/* -*- mode: c++; c-basic-offset: 3; -*- */
VCSID("@(#)$Id: TLGErrorDlg.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 
#include <cstdio>
#include <cstdlib>
#include <cstring>
//#include "TLGEntry.hh"
#include <TGMsgBox.h>
//#include <TGTableLayout.h>
#include <TPad.h>
#include <TCanvas.h>
//#include <TGFSComboBox.h>
//#include <TGListView.h>
//#include <TGFSContainer.h>
#include "TLGErrorDlg.hh"
//#include <TSystem.h>
#include <iostream>
#include <fstream>

   using namespace std;
   using namespace ligogui;

   const int kOkId = 1;
   const int kCancelId = 0;
   const int kPathId = 11 ;
   const int kDirUpId = 12 ;
   const int kFileId = 13 ;


// Constructor for error reporting dialog box, takes a name of a text
// file which contains the messages, and waits for the OK button to be
// clicked or the window to close.  If the file doesn't exist, returns
// null.
   TLGErrorDialog::TLGErrorDialog(const TGWindow *p, const TGWindow *main, const char *fname, TGString title) : TLGTransientFrame (p, main, 10, 10)
   {
      // This stuff is done for each constructor.
      CommonSetup(p, main, title) ;

      // Fill in the text box.
      fText->LoadFile(fname) ;

      fClient->WaitFor(this) ;
   }
// Constructor for error reporting dialog box.  Takes a vector of strings,
// display the messages, and wait for the OK button to be clicked or the 
// window to close.
   TLGErrorDialog::TLGErrorDialog(const TGWindow *p, const TGWindow *main, vector<string> *errors, TGString title) : TLGTransientFrame (p, main, 10, 10)
   {
      // This stuff is done for each constructor.
      CommonSetup(p, main, title) ;

      // Fill in the text box
      for (std::vector<std::string>::iterator i = errors->begin(); i != errors->end(); ++i)
      {
	 fText->AddLine(i->c_str()) ;
      }

      // Wait for user to close the window.
      fClient->WaitFor(this) ;
   }

   void
   TLGErrorDialog::CommonSetup(const TGWindow *p, const TGWindow *main, TGString title)
   {
      UInt_t box_width = 600 ;
      UInt_t box_height = 700 ;
      UInt_t button_width = 65 ;
      UInt_t button_height = 24 ;

      // Set the width and height for the overall error dialog.
      SetWidth(box_width) ;
      SetHeight(box_height) ;

      // Layout hints.
      // kLHintsLeft places the frame to the left of the container frame after other frames with the same hint
      // into the list.
      // kLHintsTop places the frame position to the top of the container frame, below any laid out frames
      // with the same hint in the list.
      // kLHintsCenterX places the frame position centered hoizontally (in veritical containers).
      // kLHintsExpandX specifies the frame to be expanded to the width of the container frame.
      // kLHintsExpandY specifies the frame to be expanded to the height of the container frame.
      //
      // This window should have two frames in a vertical arrangement.  The bottom one, containing the
      // OK button, should have a fixed height of button_height+4 (2 pixels on top and bottom).  The width
      // of the frame should be expanded to the width of the window, but the button width is fixed at 
      // 65 pixels.
      //
      fL[0] = new TGLayoutHints(kLHintsLeft | kLHintsTop | kLHintsCenterX | kLHintsExpandY, 2, 2, 2, 2) ; // Group frame layout
      fL[1] = new TGLayoutHints(kLHintsLeft | kLHintsBottom | kLHintsCenterX ,2, 2, 2, 2) ; // Ok button layout
      fL[2] = new TGLayoutHints(kLHintsLeft | kLHintsTop | kLHintsExpandX | kLHintsExpandY ,2, 2, 2, 2) ; // TextView layout

      // Horizontal frame to hold the OK button.
      fFButton = new TGHorizontalFrame(this, box_width, button_height) ;
      // This is the TLGTransientFrame's AddFrame().  Add the new frame to the transient frame.
      AddFrame(fFButton, fL[1]) ;

      // Ok button
      fOk = new TGTextButton(fFButton, "OK", kOkId) ;
      fOk->Associate(this) ;
      // Add the button to the fFButton frame, with no layout hints.
      fFButton->AddFrame(fOk, 0) ;
      // Move the button and resize it.  X, Y, width, height.
      fOk->MoveResize(box_width/2 - button_width/2, box_height, button_width, button_height) ;

      // Create a group frame to put a nice titled border around the text box for the errors.
//      fG = new TGGroupFrame(this, "Matlab Merge Errors") ;
      fG = new TGGroupFrame(this, title) ;
      // This is the TLGTransientFrame's AddFrame().  Add the new TGGroupFrame to the transient frame.
      AddFrame(fG, fL[0]) ;
      
      // Create a text object to display the errors.
      fText = new TGTextView(fG, box_width - 8, box_height - 8 - button_height) ;
      fText->Associate(this) ;  
      fG->AddFrame(fText, fL[2]) ;
      fText->Clear() ;


      // resize & move to center
      MapSubwindows ();
      UInt_t width  = GetDefaultWidth();
      UInt_t height = GetDefaultHeight();
      Resize (width, height);
      Int_t ax;
      Int_t ay;
      if (main) {
         Window_t wdum;
         gVirtualX->TranslateCoordinates (main->GetId(), GetParent()->GetId(),
                              (((TGFrame*)main)->GetWidth() - fWidth) >> 1, 
                              (((TGFrame*)main)->GetHeight() - fHeight) >> 1,
                              ax, ay, wdum);
      }
      else {
         UInt_t root_w, root_h;
         gVirtualX->GetWindowSize (fClient->GetRoot()->GetId(), ax, ay, 
                              root_w, root_h);
         ax = (root_w - fWidth) >> 1;
         ay = (root_h - fHeight) >> 1;
      }
      Move (ax, ay);
      SetWMPosition (ax, ay);
   
      // make the message box non-resizable
      SetWMSize(width, height);
      SetWMSizeHints(width, height, width, height, 0, 0);
   
      // Set the dialog box title
//      SetWindowName("Matlab Merge Errors") ;
      SetWindowName(title.GetString()) ;
      SetIconName("Errors") ;
      SetClassHints("MergeDlg`", "MergeDlg`") ;
      SetMWMHints(kMWMDecorAll | kMWMDecorResizeH  | kMWMDecorMaximize |
	      kMWMDecorMinimize | kMWMDecorMenu,
	      kMWMFuncAll  | kMWMFuncResize    | kMWMFuncMaximize |
	      kMWMFuncMinimize,
	      kMWMInputModeless);

      MapWindow() ;
   }

   // Destructor for error reporting dialog box.
   TLGErrorDialog::~TLGErrorDialog()
   {
      if (fOk)
	 delete fOk ;
      if (fText)
	 delete fText ;
      if (fFButton)
	 delete fFButton ;
      if (fG)
	 delete fG ;
      for (int i = 0; i < 3; i++)
	 if (fL[i])
	    delete fL[i] ;

   }

   // Method to call if the window needs to be closed from the application.
   void TLGErrorDialog::CloseWindow()
   {
      DeleteWindow() ; // From the sub classes.
   }

   Bool_t TLGErrorDialog::ProcessMessage(Long_t msg, Long_t parm1, Long_t parm2)
   {
      // Only one button.
      if ((GET_MSG (msg) == kC_COMMAND) && (GET_SUBMSG (msg) == kCM_BUTTON))
      {
	 switch (parm1)
	 {
	    // Ok.
	    case kOkId:
	    {
	       // Nothing to do, really.
	       DeleteWindow() ;
	       break ;
	    }
	    default:
	    case kCancelId:
	    {
	       DeleteWindow() ;
	       break ;
	    }
	 }
      }
      return kTRUE ;
   }

==> gds-2.17.3.tar.gz: gds-2.17.3/GUI/ligogui/TLGErrorDlg.cc <==
/* -*- mode: c++; c-basic-offset: 3; -*- */
VCSID("@(#)$Id: TLGErrorDlg.cc 7389 2015-06-11 18:51:56Z james.batch@LIGO.ORG $");
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <TGMsgBox.h>
//#include <TGTableLayout.h>
#include <TPad.h>
#include <TCanvas.h>
//#include <TGFSComboBox.h>
//#include <TGListView.h>
//#include <TGFSContainer.h>
#include "TLGErrorDlg.hh"
//#include <TSystem.h>
#include <iostream>
#include <fstream>

   using namespace std;
//   using namespace ligogui;

   const int kOkId = 1;
   const int kCancelId = 0;


// Constructor for error reporting dialog box, takes a name of a text
// file which contains the messages, and waits for the OK button to be
// clicked or the window to close.  If the file doesn't exist, returns
// null.
   TLGErrorDialog::TLGErrorDialog(const TGWindow *p, const TGWindow *main, const char *fname, TGString title) : TGTransientFrame (p, main, 10, 10)
   {
      // This stuff is done for each constructor.
      CommonSetup(p, main, title) ;

      // Fill in the text box.
      fText->LoadFile(fname) ;

      fClient->WaitFor(this) ;
   }

// Constructor for error reporting dialog box.  Takes a vector of strings,
// display the messages, and wait for the OK button to be clicked or the 
// window to close.
   TLGErrorDialog::TLGErrorDialog(const TGWindow *p, const TGWindow *main, vector<string> *errors, TGString title) : TGTransientFrame (p, main, 10, 10)
   {
      // This stuff is done for each constructor.
      CommonSetup(p, main, title) ;

      // Fill in the text box
      for (std::vector<std::string>::iterator i = errors->begin(); i != errors->end(); ++i)
      {
	 fText->AddLine(i->c_str()) ;
      }

      // Wait for user to close the window.
      fClient->WaitFor(this) ;
   }

// Constructor for error reporting dialog box.  Takes an array of char *,
// display the messages, and wait for the OK button to be clicked or the 
// window to close.
   TLGErrorDialog::TLGErrorDialog(const TGWindow *p, const TGWindow *main, const char *errors[], TGString title) : TGTransientFrame (p, main, 10, 10)
   {
      int i = 0 ;

      // This stuff is done for each constructor.
      CommonSetup(p, main, title) ;

      // Fill in the text box
      while (errors[i] != (char *) NULL)
      {
	 fText->AddLine(errors[i]) ;
	 ++i ;
      }

      // Wait for user to close the window.
      fClient->WaitFor(this) ;
   }

   void
   TLGErrorDialog::CommonSetup(const TGWindow *p, const TGWindow *main, TGString title)
   {
      UInt_t box_width = 600 ;
      UInt_t box_height = 700 ;
      UInt_t button_width = 65 ;
      UInt_t button_height = 24 ;

      // Set the width and height for the overall error dialog.
      SetWidth(box_width) ;
      SetHeight(box_height) ;

      // Layout hints.
      // kLHintsLeft places the frame to the left of the container frame after other frames with the same hint
      // into the list.
      // kLHintsTop places the frame position to the top of the container frame, below any laid out frames
      // with the same hint in the list.
      // kLHintsCenterX places the frame position centered hoizontally (in veritical containers).
      // kLHintsExpandX specifies the frame to be expanded to the width of the container frame.
      // kLHintsExpandY specifies the frame to be expanded to the height of the container frame.
      //
      // This window should have two frames in a vertical arrangement.  The bottom one, containing the
      // OK button, should have a fixed height of button_height+4 (2 pixels on top and bottom).  The width
      // of the frame should be expanded to the width of the window, but the button width is fixed at 
      // 65 pixels.
      //
      fL[0] = new TGLayoutHints(kLHintsLeft | kLHintsTop | kLHintsCenterX | kLHintsExpandY, 2, 2, 2, 2) ; // Group frame layout
      fL[1] = new TGLayoutHints(kLHintsLeft | kLHintsBottom | kLHintsCenterX ,2, 2, 2, 2) ; // Ok button layout
      fL[2] = new TGLayoutHints(kLHintsLeft | kLHintsTop | kLHintsExpandX | kLHintsExpandY ,2, 2, 2, 2) ; // TextView layout

      // Horizontal frame to hold the OK button.
      fFButton = new TGHorizontalFrame(this, box_width, button_height) ;
      // This is the TGTransientFrame's AddFrame().  Add the new frame to the transient frame.
      AddFrame(fFButton, fL[1]) ;

      // Ok button
      fOk = new TGTextButton(fFButton, "OK", kOkId) ;
      fOk->Associate(this) ;
      // Add the button to the fFButton frame, with no layout hints.
      fFButton->AddFrame(fOk, 0) ;
      // Move the button and resize it.  X, Y, width, height.
      fOk->MoveResize(box_width/2 - button_width/2, box_height, button_width, button_height) ;

      // Create a group frame to put a nice titled border around the text box for the errors.
      fG = new TGGroupFrame(this, title) ;
      // This is the TGTransientFrame's AddFrame().  Add the new TGGroupFrame to the transient frame.
      AddFrame(fG, fL[0]) ;
      
      // Create a text object to display the errors.
      fText = new TGTextView(fG, box_width - 8, box_height - 8 - button_height) ;
      fText->Associate(this) ;  
      fG->AddFrame(fText, fL[2]) ;
      fText->Clear() ;


      // resize & move to center
      MapSubwindows ();
      UInt_t width  = GetDefaultWidth();
      UInt_t height = GetDefaultHeight();
      Resize (width, height);
      Int_t ax;
      Int_t ay;
      if (main) {
         Window_t wdum;
         gVirtualX->TranslateCoordinates (main->GetId(), GetParent()->GetId(),
                              (((TGFrame*)main)->GetWidth() - fWidth) >> 1, 
                              (((TGFrame*)main)->GetHeight() - fHeight) >> 1,
                              ax, ay, wdum);
      }
      else {
         UInt_t root_w, root_h;
         gVirtualX->GetWindowSize (fClient->GetRoot()->GetId(), ax, ay, 
                              root_w, root_h);
         ax = (root_w - fWidth) >> 1;
         ay = (root_h - fHeight) >> 1;
      }
      Move (ax, ay);
      SetWMPosition (ax, ay);
   
      // make the message box non-resizable
      SetWMSize(width, height);
      SetWMSizeHints(width, height, width, height, 0, 0);
   
      // Set the dialog box title
      SetWindowName(title.GetString()) ;
      SetIconName("Errors") ;
      //SetClassHints("MergeDlg`", "MergeDlg`") ;
      SetMWMHints(kMWMDecorAll | kMWMDecorResizeH  | kMWMDecorMaximize |
	      kMWMDecorMinimize | kMWMDecorMenu,
	      kMWMFuncAll  | kMWMFuncResize    | kMWMFuncMaximize |
	      kMWMFuncMinimize,
	      kMWMInputModeless);

      MapWindow() ;
   }

   // Destructor for error reporting dialog box.
   TLGErrorDialog::~TLGErrorDialog()
   {
      if (fOk)
	 delete fOk ;
      if (fText)
	 delete fText ;
      if (fFButton)
	 delete fFButton ;
      if (fG)
	 delete fG ;
      for (int i = 0; i < 3; i++)
	 if (fL[i])
	    delete fL[i] ;

   }

   // Method to call if the window needs to be closed from the application.
   void TLGErrorDialog::CloseWindow()
   {
      DeleteWindow() ; // From the sub classes.
   }

   Bool_t TLGErrorDialog::ProcessMessage(Long_t msg, Long_t parm1, Long_t parm2)
   {
      // Only one button.
      if ((GET_MSG (msg) == kC_COMMAND) && (GET_SUBMSG (msg) == kCM_BUTTON))
      {
	 switch (parm1)
	 {
	    // Ok.
	    case kOkId:
	    {
	       // Nothing to do, really.
	       DeleteWindow() ;
	       break ;
	    }
	    default:
	    case kCancelId:
	    {
	       DeleteWindow() ;
	       break ;
	    }
	 }
      }
      return kTRUE ;
   }
